﻿using System.Windows;
using Infragistics.Windows.DataPresenter;
using System.Windows.Data;
using System.Collections.ObjectModel;
using System.Windows.Input;

// See the note in Control_MouseEnter


namespace ErrorPropertyIssueForInfragistics
{
	/// <summary>
	/// Interaction logic for MainWindow.xaml
	/// </summary>
	public partial class MainWindow : Window
	{
		ObservableCollection<FactorRow> FactorsCollection { get; set; }

		public MainWindow()
		{
			InitializeComponent();

			FactorsCollection = new ObservableCollection<FactorRow>();

			// create a single entry observable collection to keep it simple

			FactorRow fr = new FactorRow();
			fr.Name = "Name 0";
			fr.Factors = new Factor[5];
			fr.Factors[0] = new Factor() { FactorValue = 0.0 };
			fr.Factors[1] = new Factor() { FactorValue = 1.1 };
			fr.Factors[2] = new Factor() { FactorValue = 2.2 };
			fr.Factors[3] = new Factor() { FactorValue = 3.3 };
			fr.Factors[4] = new Factor() { FactorValue = 4.4 };
			this.FactorsCollection.Add(fr);

			FieldLayout fl = new FieldLayout();


			// Now dynamically define the xamDataGrid info that it needs to display our data

			Field f = new Field("Name");
			f.Label = "xxx";
			//f.Settings.CellValuePresenterStyle = (Style)idgvFactors.FindResource("RowLabelCellsStyle");
			f.Settings.LabelTextAlignment = TextAlignment.Left;
			//f.Settings.LabelPresenterStyle = (Style)idgvFactors.FindResource("TitleLabelCellStyle");
			f.Width = FieldLength.Auto;
			f.Settings.AllowEdit = false;
			f.Settings.AllowResize = false;

			fl.Fields.Add(f);

			// we do this slightly differently in the real app - we don't actually walk the columns in the first row of the collection - but for simplicity...

			foreach (FactorRow frc in this.FactorsCollection)
			{
				int i = 0;
				// create a binding for each column in the Factors array (this can vary so we can't just hard code it in the xaml).
				foreach (Factor factor in frc.Factors)
				{
					UnboundField uf = new UnboundField();
					uf.BindingPath = new PropertyPath(string.Format("Factors[{0}].FactorValue", i));
					uf.BindingMode = System.Windows.Data.BindingMode.TwoWay;
					uf.Label = string.Format("Col {0}", i);
					uf.Name = string.Format("Col {0}", i);
					uf.DataType = typeof(double);
					uf.Settings.LabelTextWrapping = TextWrapping.Wrap;
					uf.Settings.CellValuePresenterStyle = (Style)idgvFactors.FindResource("FactorCellsStyle");
					uf.Settings.AllowResize = false;

					// create a binding for the error information so that we can display in on mouse enter 
					// this may not be needed if we can get to the actual underlying Factor object 

					Binding ttBinding = new Binding()
						{
							Path = new PropertyPath(string.Format("Factors[{0}].Error", i)),
							RelativeSource = new RelativeSource(RelativeSourceMode.Self)
						};
					BindingOperations.SetBinding(uf, UnboundField.ToolTipProperty, ttBinding);

					fl.Fields.Add(uf);
					i++;
				}

				idgvFactors.FieldLayouts.Add(fl);
			}
			idgvFactors.DataSource = this.FactorsCollection;
		}

		private void Control_MouseEnter(object sender, MouseEventArgs e)
		{
			if (sender is CellValuePresenter)
			{
				CellValuePresenter cvp = sender as CellValuePresenter;
				if (cvp.Field != null)
				{
					Field f = cvp.Field;
					if (f.Name != "Name")
					{

// When hovering over any of the amount fields on the grid how can I use either the CellValuePresenter or the Field (or some other property) to get to the actual underlying object so that I can display its "Error" property??

					}
				}
			}
			e.Handled = true;
		}

		private void Control_MouseLeave(object sender, MouseEventArgs e)
		{
			this.tbHelp.Text = string.Empty;
			e.Handled = true;
		}

	}

}